@@ -329,7 +329,7 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
     print(f"Configuration successfully edited and saved at {output_config_dir}")
 
 
-def train(ckpt_dir='', config_dir='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
+def train(ckpt_dir='', config_dir='', train_steps=None, use_tpu=False, checkpoint_every_n=100,
           record_summaries=True):
 
     if config_dir.endswith('.config'):
